==> bouml_2.25.tar.gz: bouml_2.25/src/dialog/AnnotationDialog.h <==
// *************************************************************************
//
// Copyright (C) 2004-2007 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef ANNOTATIONDIALOG_H
#define ANNOTATIONDIALOG_H

#include <qdialog.h>

#include "DialogUtil.h"
#include "BrowserNode.h"

class QComboBox;
class MultiLineEdit;

class AnnotationDialog : public QDialog {
  Q_OBJECT
    
  protected:
    QString & value;
    MultiLineEdit * e;
    QComboBox * cb;
    BrowserNodeList annotations;
    
    static QSize previous_size;
  
  public:
    AnnotationDialog(QString & s, bool visit);
    virtual ~AnnotationDialog();
  
  protected slots:
    virtual void accept();
    void add_annotation();

  
};

#endif

==> bouml_4.16.2.orig.tar.gz: bouml_4.16.2/src/dialog/AnnotationDialog.h <==
// *************************************************************************
//
// Copyright 2004-2009 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef ANNOTATIONDIALOG_H
#define ANNOTATIONDIALOG_H

#include <qdialog.h>

#include "DialogUtil.h"
#include "BrowserNode.h"

class QComboBox;
class MultiLineEdit;

class AnnotationDialog : public QDialog {
  Q_OBJECT
    
  protected:
    QString & value;
    MultiLineEdit * e;
    QComboBox * cb;
    BrowserNodeList annotations;
    
    static QSize previous_size;
  
  public:
    AnnotationDialog(QWidget * parent, QString & s, bool visit);
    virtual ~AnnotationDialog();
  
  protected slots:
    virtual void accept();
    void add_annotation();

  
};

#endif
